@@ -6,6 +6,7 @@ import itertools
 import json
 import os
 import pathlib
+import re
 import subprocess
 import sys
 import time
@@ -13,7 +14,10 @@ from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
 
 import requests
 
-from yea import context, testcfg, testspec
+from yea import context, registry, testcfg, testspec
+
+
+RE_TESTNAME = re.compile(r"t(?P<id>\d+)_(?P<name>[a-zA-z]\w+)$")
 
 
 def run_command(
@@ -114,16 +118,62 @@ class YeaTest:
         self._yc = yc
         self._args = yc._args
         self._retcode: int
+        self._time: float
         self._test_cfg: testcfg.TestlibConfig
         self._covrc: Optional[pathlib.Path] = None
         self._time_start: Optional[Union[int, float]] = None
         self._time_end: Optional[Union[int, float]] = None
         self._permute_groups: Optional[List[Any]] = None
         self._permute_items: Optional[Tuple[Any, ...]] = None
+        self._yearc_list: List[configparser.ConfigParser] = []
+        self._registry: Optional["registry.Registry"] = None
+        self._permute_id: str = ""
+        self._profile_file: Optional[pathlib.Path] = None
 
     def __str__(self) -> str:
         return f"{self._tname}"
 
+    def _add_yearc_list(self, yearc_list: List) -> None:
+        self._yearc_list = yearc_list
+
+    def _add_registry(self, r: "registry.Registry") -> None:
+        self._registry = r
+
+    def _change_yeadoc_path(self, path: pathlib.Path) -> None:
+        self._tname = path
+
+    @property
+    def skip(self) -> bool:
+        self._load()
+        spec = self._test_cfg
+        my_platform = self._yc._get_platform()
+        suite = spec.get("tag", {}).get("suite", "main")
+        shards = spec.get("tag", {}).get("shards", [])
+        shard = spec.get("tag", {}).get("shard", "default")
+        platforms = spec.get("tag", {}).get("platforms", [])
+        shards.append(shard)
+        skip_all = spec.get("tag", {}).get("skip", False)
+        skips = spec.get("tag", {}).get("skips", [])
+        if skip_all:
+            return True
+        for skip in skips:
+            skip_platform = skip.get("platform")
+            # right now the only specific skip is platform, if not specified skip all
+            if skip_platform is None:
+                return True
+            if skip_platform and my_platform == skip_platform:
+                return True
+        if self._args.suite and self._args.suite != suite:
+            return True
+        if self._args.shard and self._args.shard not in shards:
+            return True
+        if platforms and my_platform not in platforms:
+            return True
+        # if we specify platform, skip any platform that doesn't match
+        if self._args.platform and my_platform not in platforms:
+            return True
+        return False
+
     def _depend_files(self) -> bool:
         err = False
         dep = self._test_cfg.get("depend", {})
@@ -185,6 +235,22 @@ class YeaTest:
 
         return err
 
+    @property
+    def is_yeadoc(self) -> bool:
+        for cf in self._yearc_list:
+            # for now, just yeadoc specifier
+            is_yeadoc = cf.getboolean("yea", "yeadoc", fallback=False)
+            if is_yeadoc:
+                return True
+        return False
+
+    @property
+    def yeadoc_id(self) -> str:
+        self._load()
+        # yeadoc must have id for now
+        test_id: str = self._test_cfg["id"]
+        return test_id
+
     def _run(self) -> None:
         tname = self._tname
         print("INFO: RUN=", tname)
@@ -215,6 +281,21 @@ class YeaTest:
             env["YEA_PARAM_NAMES"] = ",".join(self._permute_groups)
             env["YEA_PARAM_VALUES"] = ",".join(map(str, self._permute_items))
 
+        # pass profile config as env vars to be loaded by yea.setup() in test
+        # NOTE: yea.setup() will not be required in the future (hopefully)
+        profile: List[Union[str, Dict[str, Dict[str, Any]]]] = self._test_cfg.get("profile", [])
+        if profile:
+            prof_vars: str = ",".join(map(lambda p: next(iter(p)) if isinstance(p, dict) else p, profile))
+            prof_vals: List[Dict[str, Any]] = list(
+                map(lambda p: next(iter(p.items()))[1] if isinstance(p, dict) else {}, profile)
+            )
+            env["YEA_PROFILE_VARS"] = prof_vars
+            env["YEA_PROFILE_VALS"] = json.dumps(prof_vals)
+            prof_fname = f".profile-{self._yc._pid}-{self.test_id}"
+            prof_file = self._yc._cachedir.joinpath(prof_fname)
+            env["YEA_PROFILE_FILE"] = str(prof_file)
+            self._profile_file = prof_file
+
         plugins = self._test_cfg.get("plugin", [])
         params = (
             {k: v for (k, v) in zip(self._permute_groups, self._permute_items)}
@@ -247,8 +328,12 @@ class YeaTest:
                     env[f"YEA_PLUGIN_{penv}_VALUES"] = json.dumps(pvalues)
             env["YEA_PLUGINS"] = ",".join(plugins)
 
+        start_time = time.monotonic()
         exit_code = run_command(cmd_list, env=env, timeout=timeout)
+        end_time = time.monotonic()
+
         self._retcode = exit_code
+        self._time = end_time - start_time
 
     def _load(self) -> None:
         spec = None
@@ -357,9 +442,7 @@ class YeaTest:
             t._permute_groups = gnames
             t._permute_items = it
             tpname = f"{tnum}-{'-'.join(map(str, it))}"
-            tid = t._test_cfg.get("id")
-            if tid:
-                t._test_cfg["id"] = f"{tid}.{tpname}"
+            t._permute_id = tpname
             r.append(t)
         return r
 
@@ -373,7 +456,62 @@ class YeaTest:
 
     @property
     def test_id(self) -> Optional[str]:
-        tid = str(self._test_cfg.get("id", "")) if self._test_cfg else None
+        root = self._yc._cfg._cfroot
+        leaf_id = ""
+
+        # parse leaf id from filename
+        m = RE_TESTNAME.match(self._tname.stem)
+        if m:
+            leaf_id = m["id"]
+
+        # or parse leaf id from test_cfg
+        if not leaf_id:
+            test_cfg_id = self._test_cfg.get("id", "")
+            # ignore old form ids
+            if "." not in test_cfg_id:
+                leaf_id = test_cfg_id
+
+        # fallback use filename stem
+        if not leaf_id:
+            leaf_id = self._tname.stem
+
+        parts = [leaf_id]
+
+        # walk until root or base, picking up ids
+        # TODO: use registry yearc probed cache, self._yearc_list
+        for p in self._tname.parents:
+            base = False
+            part_id = ""
+            if p == root:
+                break
+
+            # find part_id from dirname
+            m = RE_TESTNAME.match(p.stem)
+            if m:
+                part_id = m["id"]
+
+            # always parse yearc
+            yearc = p / ".yearc"
+            if yearc.exists():
+                cf = configparser.ConfigParser()
+                cf.read(yearc)
+                # do not walk past the base
+                base = cf.getboolean("yea", "base", fallback=False)
+                # use part_id from yearc
+                if not part_id:
+                    part_id = cf.get("yea", "id", fallback="")
+
+            if not part_id:
+                part_id = p.stem
+            parts.insert(0, part_id)
+            if base:
+                break
+
+        # add a part for permutations
+        if self._permute_id:
+            parts.append(self._permute_id)
+
+        tid = ".".join(parts)
         return tid
 
     @property
